@@ -607,7 +607,7 @@ class GoodData:
         response = self.session.post(url, headers=self.headers, data=json.dumps(body))
         ## OK
         if response.status_code == 200:
-            return ExportJob(None, response.json()["uri"], gd)
+            return ExportJob(None, response.json()["uri"], self.gd)
         ## Too Many Requests
         if response.status_code == 429:
             self.logger.warning(
